@@ -1,7 +1,7 @@
 #ifndef __GDICT_APP_H_
 #define __GDICT_APP_H_
 
-/* $Id: gdict-app.h,v 1.26 2004/12/17 17:15:17 vnoel Exp $ */
+/* $Id: gdict-app.h,v 1.28 2005/01/18 21:43:02 vnoel Exp $ */
 
 /*
  *  Mike Hughes <mfh@psilord.com>
@@ -44,6 +44,7 @@ struct _GDictWindow {
 	GtkActionGroup *edit_actions;
 	GtkActionGroup *search_type_actions;
 	GtkWidget *statusbar;
+  GtkWidget *paned;
 	GDictDefbox *defbox;
 	GtkWidget *word_entry;
 	GtkWidget *gnome_word_entry;
@@ -54,10 +55,10 @@ struct _GDictWindow {
 	GtkWidget *pref_dialog;
 	GDictPref *pref;
 
-        gchar *find_text;
-        gboolean search_from_beginning;       
+  gchar *find_text;
+  gboolean search_from_beginning;       
 
-        gpointer applet;
+  gpointer applet;
 	gpointer speller;
 	gboolean speller_visible;
 
@@ -75,11 +76,13 @@ struct _GDictWindowClass {
 	GtkWindowClass parent_class;
 };
 
-void gdict_app_do_lookup (GDictWindow *gdict, gchar *text);
-void gdict_app_show_preferences (GDictWindow *gdict);
+void gdict_lookup_definition (GDictWindow *gdict, gchar *text);
+gint gdict_lookup_spelling (GDictWindow *gdict, gchar *text, gboolean pattern);
+void gdict_lookup_web (GDictWindow *gdict, gchar *text);
 GType gdict_window_get_type (void);
 GtkWidget *gdict_window_new (void);
 gint gdict_init_context (GDictWindow *gdict);
-gint gdict_spell (GDictWindow *gdict, gchar *text, gboolean pattern);
+void gdict_socket_error_cb (GtkWidget *widget, const gchar *message, gpointer data);
+void gdict_menus_set_sensitive (GDictWindow *gdict, gboolean found_definition);
 
 #endif /* __GDICT_APP_H_ */
