@@ -789,13 +789,13 @@ open_file_with_nautilus (GtkWidget * window,
 	gchar * command;
 	gchar * escaped;
 
-	escaped = escape_single_quotes (file);
+	escaped = g_shell_quote (file);
 
 	command = g_strconcat ("nautilus ", 
 	                       "--sm-disable ",
 	                       "--no-desktop ", 
 	                       "--no-default-window ",
-			       "'", escaped, "'", 
+	                       escaped, 
 	                       NULL);
 	gdk_x11_window_set_user_time (window->window, 0);
 	g_spawn_command_line_async (command, NULL);
